@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -38,6 +38,7 @@
 #include "main.hh"
 #include "ttcn3/profiler.h"
 #include "ttcn3/Attributes.hh"
+#include "ttcn3/Ttcnstuff.hh"
 
 namespace Common {
 
@@ -604,6 +605,14 @@ namespace Common {
                      get_scope_name().c_str());
     return 0;
   }
+  
+  const Ttcn::ClassTypeBody* Scope::get_scope_class() const
+  {
+    if (parent_scope != NULL) {
+      return parent_scope->get_scope_class();
+    }
+    return NULL;
+  }
 
   bool Scope::has_ass_withId(const Identifier& p_id)
   {
