@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -1872,7 +1872,7 @@ namespace Asn {
     left->generate_code(target);
     const_def cdef;
     Code::init_cdef(&cdef);
-    left->generate_code_object(&cdef, right);
+    left->generate_code_object(&cdef, right, false);
     cdef.init = right->generate_code_init(cdef.init,
       right->get_lhs_name().c_str());
     Code::merge_cdef(target, &cdef);
