@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -226,7 +226,9 @@ void def_encdec(const char *p_classname,
      "      TTCN_EncDec_ErrorContext::error_internal\n"
      "        (\"No TEXT descriptor available for type '%%s'.\", p_td.name);\n"
      "    const unsigned char *b_data=p_buf.get_data();\n"
+     "    int null_added=0;\n"
      "    if(b_data[p_buf.get_len()-1]!='\\0'){\n"
+     "      null_added=1;\n"
      "      p_buf.set_pos(p_buf.get_len());\n"
      "      p_buf.put_zero(8,ORDER_LSB);\n"
      "      p_buf.rewind();\n"
@@ -235,6 +237,12 @@ void def_encdec(const char *p_classname,
      "      ec.error(TTCN_EncDec::ET_INCOMPL_MSG,"
      "\"Can not decode type '%%s', because invalid or incomplete"
      " message was received\", p_td.name);\n"
+     "    if(null_added){\n"
+     "      size_t actpos=p_buf.get_pos();\n"
+     "      p_buf.set_pos(p_buf.get_len()-1);\n"
+     "      p_buf.cut_end();\n"
+     "      p_buf.set_pos(actpos);\n"
+     "    }\n"
      "    break;}\n"
      /* XERSTUFF decoder */
      "  case TTCN_EncDec::CT_XER: {\n"
