@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -100,7 +100,7 @@ boolean generate_skeleton = FALSE, force_overwrite = FALSE,
   warnings_for_bad_variants = FALSE, debugger_active = FALSE,
   legacy_unbound_union_fields = FALSE, split_to_slices = FALSE,
   legacy_untagged_union, disable_user_info, legacy_codec_handling = FALSE,
-  realtime_features = FALSE;
+  realtime_features = FALSE, oop_features = FALSE;
 
 // Default code splitting mode is set to 'no splitting'.
 CodeGenHelper::split_type code_splitting_mode = CodeGenHelper::SPLIT_NONE;
@@ -395,7 +395,7 @@ static boolean is_valid_asn1_filename(const char* file_name)
 static void usage()
 {
   fprintf(stderr, "\n"
-    "usage: %s [-abcdDeEfgiIjlLMnNOpqrRsStuwxXyY] [-J file] [-K file] [-z file] [-V verb_level]\n"
+    "usage: %s [-abcdDeEfFgiIjlLMnNOpqrRsStuwxXyY0] [-J file] [-K file] [-z file] [-V verb_level]\n"
     "	[-o dir] [-U none|type|'number'] [-P modulename.top_level_pdu_name] [-Q number] ...\n"
     "	[-T] module.ttcn [-A] module.asn ...\n"
     "	or  %s -v\n"
@@ -411,6 +411,7 @@ static void usage()
     "	-e:		enforce legacy handling of 'encode' and 'variant' attributes\n"
     "	-E:		display only warnings for unrecognized encoding variants\n"
     "	-f:		force overwriting of output files\n"
+    "	-F:		force generation of records of/sets of basic types and remove their compatibility\n"
     "	-g:		emulate GCC error/warning message format\n"
     "	-i:		use only line numbers in error/warning messages\n"
     "	-I:		enable real-time testing features\n"
@@ -442,6 +443,7 @@ static void usage()
     "	-y:		disable subtype checking\n"
     "	-Y:		enforce legacy behaviour for \"out\" function parameters (see refguide)\n"
     "	-z file:	enable profiling and code coverage for the TTCN-3 files in the argument\n"
+    "	-0:		disable attribute checks for `encvalue' and `decvalue'\n"
     "	-T file:	force interpretation of file as TTCN-3 module\n"
     "	-A file:	force interpretation of file as ASN.1 module\n"
     "	-v:		show version\n"
@@ -501,7 +503,7 @@ int main(int argc, char *argv[])
     Sflag = false, Kflag = false, jflag = false, zflag = false, Fflag = false,
     Mflag = false, Eflag = false, nflag = false, Bflag = false, errflag = false,
     print_usage = false, ttcn2json = false, Nflag = false, Dflag = false,
-    eflag = false, Oflag = false, Iflag = false;
+    eflag = false, Oflag = false, Iflag = false, kflag = false;
 
   CodeGenHelper cgh;
 
@@ -597,7 +599,7 @@ int main(int argc, char *argv[])
 
   if (!ttcn2json) {
     for ( ; ; ) {
-      int c = getopt(argc, argv, "aA:bBcC:dDeEfFgiIjJ:K:lLMnNo:OpP:qQ:rRsStT:uU:vV:wxXyYz:0-");
+      int c = getopt(argc, argv, "aA:bBcC:dDeEfFgiIjJ:kK:lLMnNo:OpP:qQ:rRsStT:uU:vV:wxXyYz:0-");
       if (c == -1) break;
       switch (c) {
       case 'a':
@@ -678,6 +680,13 @@ int main(int argc, char *argv[])
       case 'J':
         file_list_file_name = optarg;
         break;
+      case 'k':
+        SET_FLAG(k);
+        //oop_features = TRUE;
+        // disabled for the release
+        errflag = true;
+        print_usage = true;
+        break;
       case 'K':
         SET_FLAG(K);
         tcov_file_name = optarg;
@@ -844,7 +853,7 @@ int main(int argc, char *argv[])
         bflag || fflag || iflag || lflag || oflag || pflag || qflag ||
         rflag || sflag || tflag || uflag || wflag || xflag || Xflag || Rflag ||
         Uflag || yflag || Kflag || jflag || zflag || Fflag || Mflag || Eflag ||
-        nflag || Bflag || Dflag || eflag || Oflag || Iflag) {
+        nflag || Bflag || Dflag || eflag || Oflag || Iflag || s0flag || kflag) {
         errflag = true;
         print_usage = true;
       }
@@ -877,6 +886,10 @@ int main(int argc, char *argv[])
       output_dir);
         errflag = true;
       }
+      if (s0flag && !sflag) {
+        ERROR("Option `-0' requires option `-s'");
+        errflag = true;
+      }
       
       if (file_list_file_name != NULL) {
         FILE *fp = fopen(file_list_file_name, "r");
@@ -956,6 +969,7 @@ int main(int argc, char *argv[])
   if (vflag) {
     fputs("TTCN-3 and ASN.1 Compiler for the TTCN-3 Test Executor\n"
 	  "Product number: " PRODUCT_NUMBER "\n"
+	  "Version: " VERSION_STRING "\n"
 	  "Build date: " __DATE__ " " __TIME__ "\n"
 	  "Compiled with: " C_COMPILER_VERSION "\n", stderr);
 	  fputs("Using ", stderr);
