@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -69,6 +69,7 @@ RawAST::RawAST(RawAST *other, int default_length){
     length_restrition=other->length_restrition;
     intx = other->intx;
     stringformat = other->stringformat;
+    csn1lh = other->csn1lh;
     }
     else init_rawast(default_length);
 }
@@ -112,6 +113,7 @@ void RawAST::init_rawast(int default_length){
     topleveleind=0;
     intx = false;
     stringformat = CharCoding::UNKNOWN;
+    csn1lh = false;
 }
 
 RawAST::~RawAST(){
@@ -215,9 +217,10 @@ void RawAST::print_RawAST(){
     printf("%sIntX encoding\n\r", intx ? "" : "not ");
     printf("String format: %s\n\r", stringformat == CharCoding::UTF_8 ? "UTF-8" :
       (stringformat == CharCoding::UTF16 ? "UTF-16" : "unknown"));
+    printf("%susing CSN.1 L/H values\n\r", csn1lh ? "" : "not ");
 }
 
-void copy_rawAST_to_struct(RawAST *from, raw_attrib_struct *to){
+void copy_rawAST_to_struct(RawAST *from, raw_attrib_struct *to, bool copy_presences){
     to->fieldlength=from->fieldlength;
     to->comp=from->comp;
     to->byteorder=from->byteorder;
@@ -262,7 +265,7 @@ void copy_rawAST_to_struct(RawAST *from, raw_attrib_struct *to){
 	to->taglist.list[i].fields = NULL;
       }
     } else to->taglist.list = NULL;
-    to->presence.nElements = from->presence.nElements;
+    to->presence.nElements = copy_presences ? from->presence.nElements : 0;
     if (to->presence.nElements > 0)
       to->presence.fields = static_cast<rawAST_coding_field_list*>(
          Malloc(to->presence.nElements * sizeof(rawAST_coding_field_list)) );
@@ -324,5 +327,7 @@ int compare_raw_attrib(RawAST *a, RawAST *b){
            a->ptroffset!=b->ptroffset ||
            a->repeatable!=b->repeatable ||
            a->unit!=b->unit ||
-           a->intx != b->intx;
+           a->intx != b->intx ||
+           a->stringformat != b->stringformat ||
+           a->csn1lh != b->csn1lh;
 }
