@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -957,10 +957,18 @@ namespace Ttcn {
   : Node(), Location(), nps()
   {
   }
+  
+  NamedParams::NamedParams(const NamedParams& p)
+  : Node(p), Location(p)
+  {
+    for (size_t i = 0; i < p.nps.size(); ++i) {
+      nps.add(p.nps[i]->clone());
+    }
+  }
 
   NamedParams * NamedParams::clone() const
   {
-    FATAL_ERROR("NamedParams::clone");
+    return new NamedParams(*this);
   }
 
   NamedParams::~NamedParams()
