@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -67,6 +67,11 @@ extern "C" {
       char *start;     /**< Code for start_ptc_function() */
       char *control;   /**< Code for module_control_part() */
     } functions;
+    struct {
+      char* constructor_init;
+      char* constructor_preamble;
+      char* constructor_block;
+    } temp;
     struct {
       size_t pre_things_size; // Size of string_literals + global_vars
       size_t *methods;
