@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -116,9 +116,6 @@ typedef struct port_def_tag {
   testport_type_t testport_type;
   port_type_t port_type;
   port_msg_prov_list provider_msg_outlist;
-  const char **mapper_name;
-  boolean* mapper_realtime;
-  size_t n_mapper_name;
   port_msg_mapped_type_list provider_msg_in;
   boolean has_sliding;
   boolean legacy; // true if the old user port is used false if translation ports used
