@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -443,7 +443,7 @@ BITSTRING BITSTRING::operator>>(const INTEGER& shift_count) const
 
 BITSTRING BITSTRING::operator<<=(int rotate_count) const
 {
-  must_bound("Unbound bistring operand of rotate left operator.");
+  must_bound("Unbound bitstring operand of rotate left operator.");
   int n_bits = val_ptr->n_bits;
   if (n_bits == 0) return *this;
   if (rotate_count >= 0) {
@@ -463,7 +463,7 @@ BITSTRING BITSTRING::operator<<=(const INTEGER& rotate_count) const
 
 BITSTRING BITSTRING::operator>>=(int rotate_count) const
 {
-  must_bound("Unbound bistring operand of rotate right operator.");
+  must_bound("Unbound bitstring operand of rotate right operator.");
   int n_bits = val_ptr->n_bits;
   if (n_bits == 0) return *this;
   if (rotate_count >= 0) {
@@ -1019,6 +1019,7 @@ int BITSTRING::RAW_encode(const TTCN_Typedescriptor_t& p_td, RAW_enc_tree& mylea
   if (p_td.raw->bitorderinoctet == ORDER_MSB) orders = TRUE;
   if (p_td.raw->bitorderinfield == ORDER_LSB) orders = !orders;
   myleaf.coding_par.bitorder = orders ? ORDER_MSB : ORDER_LSB;
+  myleaf.coding_par.csn1lh = p_td.raw->csn1lh;
 
   if (p_td.raw->endianness == ORDER_MSB) myleaf.align =  align_length;
   else                                   myleaf.align = -align_length;
@@ -1055,6 +1056,7 @@ int BITSTRING::RAW_decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& buff,
   cp.byteorder = orders ? ORDER_MSB : ORDER_LSB;
   cp.fieldorder = p_td.raw->fieldorder;
   cp.hexorder = ORDER_LSB;
+  cp.csn1lh = p_td.raw->csn1lh;
   buff.get_b((size_t) decode_length, val_ptr->bits_ptr, cp, top_bit_ord);
   if (p_td.raw->length_restrition != -1 &&
       decode_length > p_td.raw->length_restrition) {
