@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -304,7 +304,9 @@ void BOOLEAN::decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
       TTCN_EncDec_ErrorContext::error_internal
         ("No TEXT descriptor available for type '%s'.", p_td.name);
     const unsigned char *b=p_buf.get_data();
+    int null_added=0;
     if(b[p_buf.get_len()-1]!='\0'){
+      null_added=1;
       p_buf.set_pos(p_buf.get_len());
       p_buf.put_zero(8,ORDER_LSB);
       p_buf.rewind();
@@ -314,6 +316,12 @@ void BOOLEAN::decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
                "Can not decode type '%s', because invalid or incomplete"
                " message was received"
                , p_td.name);
+    if(null_added){
+      size_t actpos=p_buf.get_pos();
+      p_buf.set_pos(p_buf.get_len()-1);
+      p_buf.cut_end();
+      p_buf.set_pos(actpos);
+    }
     break;}
   case TTCN_EncDec::CT_XER: {
     TTCN_EncDec_ErrorContext ec("While XER-decoding type '%s': ", p_td.name);
@@ -570,6 +578,7 @@ int BOOLEAN::RAW_encode(const TTCN_Typedescriptor_t& p_td, RAW_enc_tree& myleaf)
     // remove the extra ones from the last octet
     bc[length - 1] &= BitMaskTable[loc_length % 8];
   }
+  myleaf.coding_par.csn1lh = p_td.raw->csn1lh;
   return myleaf.length = loc_length;
 }
 
@@ -610,6 +619,7 @@ int BOOLEAN::RAW_decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& buff,
     cp.byteorder = orders ? ORDER_MSB : ORDER_LSB;
     cp.fieldorder = p_td.raw->fieldorder;
     cp.hexorder = ORDER_LSB;
+    cp.csn1lh = p_td.raw->csn1lh;
     int length = (decode_length + 7) / 8;
     unsigned char *data = (unsigned char*)Malloc(length*sizeof(unsigned char));
     buff.get_b((size_t)decode_length, data, cp, top_bit_ord);
