@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -1024,7 +1024,8 @@ void TTCN_Communication::send_disconnected(const char *local_port,
 }
 
 void TTCN_Communication::send_map_req(component src_component,
-  const char *src_port, const char *system_port, boolean translation)
+  const char *src_port, const char *system_port, Map_Params& params,
+  boolean translation)
 {
   Text_Buf text_buf;
   text_buf.push_int(MSG_MAP_REQ);
@@ -1032,22 +1033,33 @@ void TTCN_Communication::send_map_req(component src_component,
   text_buf.push_int(translation == FALSE ? 0 : 1);
   text_buf.push_string(src_port);
   text_buf.push_string(system_port);
+  unsigned int nof_params = params.get_nof_params();
+  text_buf.push_int(nof_params);
+  for (unsigned int i = 0; i < nof_params; ++i) {
+    text_buf.push_string((const char*) params.get_param(i));
+  }
   send_message(text_buf);
 }
 
 void TTCN_Communication::send_mapped(const char *local_port,
-  const char *system_port, boolean translation)
+  const char *system_port, Map_Params& params, boolean translation)
 {
   Text_Buf text_buf;
   text_buf.push_int(MSG_MAPPED);
   text_buf.push_int(translation == FALSE ? 0 : 1);
   text_buf.push_string(local_port);
   text_buf.push_string(system_port);
+  unsigned int nof_params = params.get_nof_params();
+  text_buf.push_int(nof_params);
+  for (unsigned int i = 0; i < nof_params; ++i) {
+    text_buf.push_string((const char*) params.get_param(i));
+  }
   send_message(text_buf);
 }
 
 void TTCN_Communication::send_unmap_req(component src_component,
-  const char *src_port, const char *system_port, boolean translation)
+  const char *src_port, const char *system_port, Map_Params& params,
+  boolean translation)
 {
   Text_Buf text_buf;
   text_buf.push_int(MSG_UNMAP_REQ);
@@ -1055,17 +1067,27 @@ void TTCN_Communication::send_unmap_req(component src_component,
   text_buf.push_int(translation == FALSE ? 0 : 1);
   text_buf.push_string(src_port);
   text_buf.push_string(system_port);
+  unsigned int nof_params = params.get_nof_params();
+  text_buf.push_int(nof_params);
+  for (unsigned int i = 0; i < nof_params; ++i) {
+    text_buf.push_string((const char*) params.get_param(i));
+  }
   send_message(text_buf);
 }
 
 void TTCN_Communication::send_unmapped(const char *local_port,
-  const char *system_port, boolean translation)
+  const char *system_port, Map_Params& params, boolean translation)
 {
   Text_Buf text_buf;
   text_buf.push_int(MSG_UNMAPPED);
   text_buf.push_int(translation == FALSE ? 0 : 1);
   text_buf.push_string(local_port);
   text_buf.push_string(system_port);
+  unsigned int nof_params = params.get_nof_params();
+  text_buf.push_int(nof_params);
+  for (unsigned int i = 0; i < nof_params; ++i) {
+    text_buf.push_string((const char*) params.get_param(i));
+  }
   send_message(text_buf);
 }
 
@@ -1222,8 +1244,7 @@ boolean TTCN_Communication::send_log(time_t timestamp_sec, long timestamp_usec,
     /* If an ERROR message (indicating a version mismatch) arrives from MC
 	   in state HC_IDLE (i.e. before CONFIGURE) it shall be
 	   printed to the console as well. */
-    if (TTCN_Runtime::get_state() == TTCN_Runtime::HC_IDLE) return FALSE;
-    else return TRUE;
+    return TTCN_Runtime::get_state() != TTCN_Runtime::HC_IDLE;
   } else {
     switch (TTCN_Runtime::get_state()) {
     case TTCN_Runtime::HC_EXIT:
@@ -1768,18 +1789,25 @@ void TTCN_Communication::process_map()
   boolean translation = incoming_buf.pull_int().get_val() == 0 ? FALSE : TRUE;
   char *local_port = incoming_buf.pull_string();
   char *system_port = incoming_buf.pull_string();
+  unsigned int nof_params = incoming_buf.pull_int().get_val();
+  Map_Params params(nof_params);
+  for (unsigned int i = 0; i < nof_params; ++i) {
+    char* par = incoming_buf.pull_string();
+    params.set_param(i, CHARSTRING(par));
+    delete [] par;
+  }
   incoming_buf.cut_message();
 
   try {
-    PORT::map_port(local_port, system_port, FALSE);
+    PORT::map_port(local_port, system_port, params, FALSE);
     if (translation == TRUE) {
-      PORT::map_port(local_port, system_port, TRUE);
+      PORT::map_port(local_port, system_port, params, TRUE);
     }
     if (!TTCN_Runtime::is_single()) {
       if (translation == FALSE) {
-        send_mapped(local_port, system_port, translation);
+        send_mapped(local_port, system_port, params, translation);
       } else {
-        send_mapped(system_port, local_port, translation);
+        send_mapped(system_port, local_port, params, translation);
       }
     }
   } catch (...) {
@@ -1794,6 +1822,13 @@ void TTCN_Communication::process_map()
 
 void TTCN_Communication::process_map_ack()
 {
+  unsigned int nof_params = incoming_buf.pull_int().get_val();
+  map_params_cache.reset(nof_params);
+  for (unsigned int i = 0; i < nof_params; ++i) {
+    char* par = incoming_buf.pull_string();
+    map_params_cache.set_param(i, CHARSTRING(par));
+    delete [] par;
+  }
   incoming_buf.cut_message();
 
   switch (TTCN_Runtime::get_state()) {
@@ -1814,18 +1849,25 @@ void TTCN_Communication::process_unmap()
   boolean translation = incoming_buf.pull_int().get_val() == 0 ? FALSE : TRUE;
   char *local_port = incoming_buf.pull_string();
   char *system_port = incoming_buf.pull_string();
+  unsigned int nof_params = incoming_buf.pull_int().get_val();
+  Map_Params params(nof_params);
+  for (unsigned int i = 0; i < nof_params; ++i) {
+    char* par = incoming_buf.pull_string();
+    params.set_param(i, CHARSTRING(par));
+    delete [] par;
+  }
   incoming_buf.cut_message();
 
   try {
-    PORT::unmap_port(local_port, system_port, FALSE);
+    PORT::unmap_port(local_port, system_port, params, FALSE);
     if (translation == TRUE) {
-      PORT::unmap_port(local_port, system_port, TRUE);
+      PORT::unmap_port(local_port, system_port, params, TRUE);
     }
     if (!TTCN_Runtime::is_single()) {
       if (translation == FALSE) {
-        send_unmapped(local_port, system_port, translation);
+        send_unmapped(local_port, system_port, params, translation);
       } else {
-        send_unmapped(system_port, local_port, translation);
+        send_unmapped(system_port, local_port, params, translation);
       }
     }
   } catch (...) {
@@ -1840,6 +1882,13 @@ void TTCN_Communication::process_unmap()
 
 void TTCN_Communication::process_unmap_ack()
 {
+  unsigned int nof_params = incoming_buf.pull_int().get_val();
+  map_params_cache.reset(nof_params);
+  for (unsigned int i = 0; i < nof_params; ++i) {
+    char* par = incoming_buf.pull_string();
+    map_params_cache.set_param(i, CHARSTRING(par));
+    delete [] par;
+  }
   incoming_buf.cut_message();
 
   switch(TTCN_Runtime::get_state()){
