@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -25,6 +25,7 @@
 #include <string.h>
 #include <math.h>
 #include <float.h>
+#include <locale.h>
 
 #include "../common/memory.h"
 #include "Float.hh"
@@ -60,17 +61,21 @@ const FLOAT NOT_A_NUMBER((double)PLUS_INFINITY+(double)MINUS_INFINITY);
 
 static inline void log_float(double float_val)
 {
-  if (   (float_val > -MAX_DECIMAL_FLOAT && float_val <= -MIN_DECIMAL_FLOAT)
-      || (float_val >= MIN_DECIMAL_FLOAT && float_val <   MAX_DECIMAL_FLOAT)
-      || (float_val == 0.0))
-    TTCN_Logger::log_event("%f", float_val);
-  else if(float_val==INFINITY)
+  if(float_val==INFINITY)
     TTCN_Logger::log_event_str("infinity");
   else if(float_val==-INFINITY)
     TTCN_Logger::log_event_str("-infinity");
   else if(float_val!=float_val)
     TTCN_Logger::log_event_str("not_a_number");
-  else TTCN_Logger::log_event("%e", float_val);
+  else {
+    boolean f = (float_val > -MAX_DECIMAL_FLOAT && float_val <= -MIN_DECIMAL_FLOAT)
+      || (float_val >= MIN_DECIMAL_FLOAT && float_val <   MAX_DECIMAL_FLOAT)
+      || (float_val == 0.0);
+    const char* loc = setlocale(LC_ALL, NULL);
+    setlocale(LC_NUMERIC, "C"); // use default locale for displaying numbers
+    TTCN_Logger::log_event(f ? "%f" : "%e", float_val);
+    setlocale(LC_NUMERIC, loc);
+  }
 }
 
 // float value class
@@ -760,6 +765,7 @@ int FLOAT::RAW_encode(const TTCN_Typedescriptor_t& p_td, RAW_enc_tree& myleaf) c
   else
     TTCN_EncDec_ErrorContext::error_internal("Invalid FLOAT length %d", length);
 
+  myleaf.coding_par.csn1lh = p_td.raw->csn1lh;
   return myleaf.length = p_td.raw->fieldlength;
 }
 
@@ -795,6 +801,7 @@ int FLOAT::RAW_decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& buff,
   cp.byteorder = orders ? ORDER_MSB : ORDER_LSB;
   cp.fieldorder = p_td.raw->fieldorder;
   cp.hexorder = ORDER_LSB;
+  cp.csn1lh = p_td.raw->csn1lh;
   buff.get_b((size_t) decode_length, data, cp, top_bit_ord);
   if (decode_length == 64) {
     unsigned char *dv = (unsigned char *) &tmp;
