@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -417,6 +417,12 @@ void Module_List::list_testcases()
     list_iter = list_iter->list_next) list_iter->list_testcases();
 }
 
+void Module_List::list_modulepars()
+{
+  for (TTCN_Module *list_iter = list_head; list_iter != NULL;
+    list_iter = list_iter->list_next) list_iter->list_modulepars();
+}
+
 void Module_List::push_version(Text_Buf& text_buf)
 {
   int n_modules = 0;
@@ -425,11 +431,7 @@ void Module_List::push_version(Text_Buf& text_buf)
   text_buf.push_int(n_modules);
   for (TTCN_Module *list_iter = list_head; list_iter != NULL;
     list_iter = list_iter->list_next) {
-    text_buf.push_string(list_iter->module_name);
-    if (list_iter->md5_checksum != NULL) {
-      text_buf.push_int(16);
-      text_buf.push_raw(16, list_iter->md5_checksum);
-    } else text_buf.push_int((RInt)0);
+    list_iter->push_version(text_buf);
   }
 }
 
@@ -785,6 +787,11 @@ struct TTCN_Module::testcase_list_item {
   testcase_list_item *next_testcase;
 };
 
+struct TTCN_Module::modulepar_list_item {
+  const char* name;
+  modulepar_list_item* next;
+};
+
 /** Constructor for TTCN modules */
 TTCN_Module::TTCN_Module(const char *par_module_name,
   const char *par_compilation_date,
@@ -838,6 +845,8 @@ TTCN_Module::TTCN_Module(const char *par_module_name,
 , altstep_tail(NULL)
 , testcase_head(NULL)
 , testcase_tail(NULL)
+, modulepar_head(NULL)
+, modulepar_tail(NULL)
 {
   Module_List::add_module(this);
 }
@@ -879,6 +888,8 @@ TTCN_Module::TTCN_Module(const char *par_module_name,
 , altstep_tail(NULL)
 , testcase_head(NULL)
 , testcase_tail(NULL)
+, modulepar_head(NULL)
+, modulepar_tail(NULL)
 {
   Module_List::add_module(this);
 }
@@ -918,6 +929,8 @@ TTCN_Module::TTCN_Module(const char *par_module_name,
 , altstep_tail(NULL)
 , testcase_head(NULL)
 , testcase_tail(NULL)
+, modulepar_head(NULL)
+, modulepar_tail(NULL)
 {
   Module_List::add_module(this);
  }
@@ -940,6 +953,11 @@ TTCN_Module::~TTCN_Module()
     delete testcase_head;
     testcase_head = tmp_ptr;
   }
+  while (modulepar_head != NULL) {
+    modulepar_list_item *tmp_ptr = modulepar_head->next;
+    delete modulepar_head;
+    modulepar_head = tmp_ptr;
+  }
 }
 
 void TTCN_Module::pre_init_module()
@@ -1020,6 +1038,20 @@ void TTCN_Module::add_testcase_pard(const char *testcase_name,
   testcase_tail = new_item;
 }
 
+void TTCN_Module::add_modulepar(const char* name)
+{
+  modulepar_list_item* new_item = new modulepar_list_item;
+  new_item->name = name;
+  new_item->next = NULL;
+  if (modulepar_head == NULL) {
+    modulepar_head = new_item;
+  }
+  else {
+    modulepar_tail->next = new_item;
+  }
+  modulepar_tail = new_item;
+}
+
 void TTCN_Module::execute_testcase(const char *testcase_name)
 {
   for (testcase_list_item *list_iter = testcase_head; list_iter != NULL;
@@ -1231,6 +1263,25 @@ void TTCN_Module::list_testcases()
       printf("%s.%s\n", module_name, list_iter->testcase_name);
 }
 
+void TTCN_Module::list_modulepars()
+{
+  for (modulepar_list_item *list_iter = modulepar_head; list_iter != NULL;
+       list_iter = list_iter->next) {
+    printf("%s.%s\n", module_name, list_iter->name);
+  }
+}
+
+void TTCN_Module::push_version(Text_Buf& text_buf)
+{
+  text_buf.push_string(module_name);
+  if (md5_checksum != NULL) {
+    text_buf.push_int(16);
+    text_buf.push_raw(16, md5_checksum);
+  } else {
+    text_buf.push_int((RInt)0);
+  }
+}
+
 const namespace_t *TTCN_Module::get_ns(size_t p_index) const
 {
   if (p_index == (size_t)-1) return NULL;
