@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -699,7 +699,9 @@ void OCTETSTRING::decode(const TTCN_Typedescriptor_t& p_td,
       TTCN_EncDec_ErrorContext::error_internal
         ("No TEXT descriptor available for type '%s'.", p_td.name);
     const unsigned char *b=p_buf.get_data();
+    int null_added=0;
     if(b[p_buf.get_len()-1]!='\0'){
+      null_added=1;
       p_buf.set_pos(p_buf.get_len());
       p_buf.put_zero(8,ORDER_LSB);
       p_buf.rewind();
@@ -709,6 +711,12 @@ void OCTETSTRING::decode(const TTCN_Typedescriptor_t& p_td,
                "Can not decode type '%s', because invalid or incomplete"
                " message was received"
                , p_td.name);
+    if(null_added){
+      size_t actpos=p_buf.get_pos();
+      p_buf.set_pos(p_buf.get_len()-1);
+      p_buf.cut_end();
+      p_buf.set_pos(actpos);
+    }
     break;}
   case TTCN_EncDec::CT_XER: {
     TTCN_EncDec_ErrorContext ec("While XER-decoding type '%s': ", p_td.name);
@@ -1227,6 +1235,7 @@ int OCTETSTRING::RAW_encode(const TTCN_Typedescriptor_t& p_td,
   else myleaf.body.leaf.data_ptr = val_ptr->octets_ptr;
   if (p_td.raw->endianness == ORDER_MSB) myleaf.align = align_length;
   else myleaf.align = -align_length;
+  myleaf.coding_par.csn1lh = p_td.raw->csn1lh;
   return myleaf.length = bl + align_length;
 }
 
@@ -1256,6 +1265,7 @@ int OCTETSTRING::RAW_decode(const TTCN_Typedescriptor_t& p_td,
   cp.byteorder = orders ? ORDER_MSB : ORDER_LSB;
   cp.fieldorder = p_td.raw->fieldorder;
   cp.hexorder = ORDER_LSB;
+  cp.csn1lh = p_td.raw->csn1lh;
   if (p_td.raw->extension_bit != EXT_BIT_NO) {
     const unsigned char* data = buff.get_read_data();
     int count = 1;
