@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -53,6 +53,63 @@
 
 #include "../common/dbgnew.hh"
 
+void Map_Params::init(unsigned int p_nof_params)
+{
+  nof_params = p_nof_params;
+  params = new CHARSTRING[nof_params];
+}
+
+void Map_Params::clear()
+{
+  delete[] params;
+  nof_params = 0;
+  params = NULL;
+}
+
+void Map_Params::copy(const Map_Params& p_other)
+{
+  init(p_other.nof_params);
+  for (unsigned int i = 0; i < nof_params; ++i) {
+    params[i] = p_other.params[i];
+  }
+}
+
+Map_Params& Map_Params::operator=(const Map_Params& p_other)
+{
+  clear();
+  copy(p_other);
+  return *this;
+}
+
+void Map_Params::reset(unsigned int p_nof_params)
+{
+  clear();
+  init(p_nof_params);
+}
+
+void Map_Params::set_param(unsigned int p_index, const CHARSTRING& p_param)
+{
+  if (p_index >= nof_params) {
+    TTCN_error("Map/unmap parameter index out of bounds");
+  }
+  params[p_index] = p_param;
+}
+
+unsigned int Map_Params::get_nof_params() const
+{
+  return nof_params;
+}
+
+const CHARSTRING& Map_Params::get_param(unsigned int p_index) const
+{
+  if (p_index >= nof_params) {
+    TTCN_error("Map/unmap parameter index out of bounds");
+  }
+  return params[p_index];
+}
+
+Map_Params map_params_cache(0);
+
 PORT *PORT::list_head = NULL, *PORT::list_tail = NULL;
 PORT *PORT::system_list_head = NULL, *PORT::system_list_tail = NULL;
 
@@ -356,12 +413,13 @@ void PORT::deactivate_port(boolean system)
       TTCN_Logger::log_port_misc(
         TitanLoggerApi::Port__Misc_reason::removing__unterminated__mapping,
         port_name, NULL_COMPREF, system_port);
+      Map_Params params(0);
       try {
-        unmap(system_port, system);
+        unmap(system_port, params, system);
       } catch (const TC_Error&) { }
       if (is_parallel) {
         try {
-          TTCN_Communication::send_unmapped(port_name, system_port, system);
+          TTCN_Communication::send_unmapped(port_name, system_port, params, system);
         } catch (const TC_Error&) { }
       }
       Free(system_port);
@@ -525,6 +583,12 @@ PORT* PORT::get_provider_port() {
   return NULL;
 }
 
+boolean PORT::incoming_message_handler(const void* message_ptr, const char* message_type,
+                                       component sender_component, const FLOAT& timestamp)
+{
+  return FALSE;
+}
+
 alt_status PORT::receive(const COMPONENT_template&, COMPONENT *, FLOAT*, Index_Redirect*)
 {
   TTCN_Logger::log_matching_problem(
@@ -1140,12 +1204,28 @@ void PORT::Uninstall_Handler()
   Fd_And_Timeout_User::set_timer(this, 0.0);
 }
 
-void PORT::user_map(const char *)
+void PORT::user_map(const char *system_port)
+{
+  // call the new user_map function if the legacy version is not overridden in
+  // the port implementation
+  Map_Params dummy(0);
+  user_map(system_port, dummy);
+}
+
+void PORT::user_unmap(const char *system_port)
+{
+  // call the new user_unmap function if the legacy version is not overridden in
+  // the port implementation
+  Map_Params dummy(0);
+  user_unmap(system_port, dummy);
+}
+
+void PORT::user_map(const char *, Map_Params&)
 {
 
 }
 
-void PORT::user_unmap(const char *)
+void PORT::user_unmap(const char *, Map_Params&)
 {
 
 }
@@ -2184,7 +2264,7 @@ void PORT::process_last_message(port_connection *conn_ptr)
   }
 }
 
-void PORT::map(const char *system_port, boolean translation)
+void PORT::map(const char *system_port, Map_Params& params, boolean translation)
 {
   if (!is_active) TTCN_error("Inactive port %s cannot be mapped.", port_name);
 
@@ -2209,7 +2289,13 @@ void PORT::map(const char *system_port, boolean translation)
     set_system_parameters(port_name);
   }
 
-  user_map(system_port);
+  if (params.get_nof_params() == 0) {
+    // call the legacy function if there are no parameters (for backward compatibility)
+    user_map(system_port);
+  }
+  else {
+    user_map(system_port, params);
+  }
 
   if (translation == FALSE) {
     TTCN_Logger::log_port_misc(
@@ -2235,7 +2321,7 @@ void PORT::map(const char *system_port, boolean translation)
     "addressing.", port_name);
 }
 
-void PORT::unmap(const char *system_port, boolean translation)
+void PORT::unmap(const char *system_port, Map_Params& params, boolean translation)
 {
   int del_posn;
   for (del_posn = 0; del_posn < n_system_mappings; del_posn++) {
@@ -2267,7 +2353,13 @@ void PORT::unmap(const char *system_port, boolean translation)
     n_system_mappings * sizeof(*system_mappings));
 
   try {
-    user_unmap(system_port);
+    if (params.get_nof_params() == 0) {
+      // call the legacy function if there are no parameters (for backward compatibility)
+      user_unmap(system_port);
+    }
+    else {
+      user_unmap(system_port, params);
+    }
   } catch (...) {
     // prevent from memory leak
     Free(unmapped_port);
@@ -2511,7 +2603,8 @@ void PORT::terminate_local_connection(const char *src_port,
   }
 }
 
-void PORT::map_port(const char *component_port, const char *system_port, boolean translation)
+void PORT::map_port(const char *component_port, const char *system_port,
+                    Map_Params& params, boolean translation)
 {
   if (translation == TRUE) {
     TTCN_Runtime::initialize_system_port(system_port);
@@ -2524,9 +2617,9 @@ void PORT::map_port(const char *component_port, const char *system_port, boolean
     TTCN_error("Map operation is not allowed on a connected port (%s).", port_name);
   }
   if (translation == FALSE) {
-    port_ptr->map(system_port, translation);
+    port_ptr->map(system_port, params, translation);
   } else {
-    port_ptr->map(component_port, translation);
+    port_ptr->map(component_port, params, translation);
   }
   if (translation == TRUE) {
     PORT* other_port_ptr = lookup_by_name(component_port, FALSE);
@@ -2538,7 +2631,8 @@ void PORT::map_port(const char *component_port, const char *system_port, boolean
   }
 }
 
-void PORT::unmap_port(const char *component_port, const char *system_port, boolean translation)
+void PORT::unmap_port(const char *component_port, const char *system_port,
+                      Map_Params& params, boolean translation)
 {
   if (translation == TRUE) {
     TTCN_Runtime::initialize_system_port(system_port);
@@ -2548,9 +2642,9 @@ void PORT::unmap_port(const char *component_port, const char *system_port, boole
   if (port_ptr == NULL) TTCN_error("Unmap operation refers to "
     "non-existent port %s.", port_name);
   if (translation == FALSE) {
-    port_ptr->unmap(system_port, translation);
+    port_ptr->unmap(system_port, params, translation);
   } else {
-    port_ptr->unmap(component_port, translation);
+    port_ptr->unmap(component_port, params, translation);
   }
   if (translation == TRUE) {
     PORT* other_port_ptr = lookup_by_name(component_port, FALSE);
