@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -690,7 +690,7 @@ boolean match_set_of_internal(const Base_Type *value_ptr,
             int temp_value_index;
             int actual_node;
             boolean at_end = FALSE;
-            for( ; !at_end; )
+            while(!at_end)
             {
               at_end = tree.is_head();
               actual_node = tree.actual_data();
