@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -26,7 +26,7 @@
 // Author:                Janos Zoltan Szabo
 // mail:                  tmpjsz@eth.ericsson.se
 //
-// Copyright (c) 2000-2018 Ericsson Telecom AB
+// Copyright (c) 2000-2019 Ericsson Telecom AB
 //
 #ifndef MCTR_MAINCONTROLLER_H
 #define MCTR_MAINCONTROLLER_H
@@ -381,7 +381,8 @@ class MainController {
     boolean new_connection, component_struct *requestor,
     const char *operation);
   static void destroy_connection(port_connection *conn, component_struct *tc);
-  static void destroy_mapping(port_connection *conn);
+  static void destroy_mapping(port_connection *conn, unsigned int nof_params,
+    char** params);
   static boolean stop_all_components();
   static void check_all_component_stop();
   static void send_stop_ack_to_requestors(component_struct *tc);
@@ -526,11 +527,15 @@ private:
     const char *local_port, component remote_comp, const char *remote_port);
   static void send_disconnect_ack(component_struct *tc);
   static void send_map(component_struct *tc,
-    const char *local_port, const char *system_port, boolean translate);
-  static void send_map_ack(component_struct *tc);
+    const char *local_port, const char *system_port, unsigned int nof_params,
+    char** params, boolean translate);
+  static void send_map_ack(component_struct *tc, unsigned int nof_params,
+    char** params);
   static void send_unmap(component_struct *tc,
-    const char *local_port, const char *system_port, boolean translate);
-  static void send_unmap_ack(component_struct *tc);
+    const char *local_port, const char *system_port, unsigned int nof_params,
+    char** params, boolean translate);
+  static void send_unmap_ack(component_struct *tc, unsigned int nof_params,
+    char** params);
   static void send_debug_command(int fd, int commandID, const char* arguments);
   static void send_debug_setup(host_struct *hc);
 
