@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -1258,7 +1258,7 @@ void ComplexType::printToFile(FILE * file, const unsigned level, const bool is_u
         }
       } else {
         int multiplicity = multi(module, getReference(), this);
-        if ((multiplicity > 1) && getReference().get_ref()) {
+        if (!o_flag_used && (multiplicity > 1) && getReference().get_ref()) {
           fprintf(file, "%s.", getReference().get_ref()->getModule()->getModulename().c_str());
         }
         if (field_is_record || field_is_union || listPrint) {
@@ -1826,23 +1826,27 @@ void ComplexType::resolveGroup() {
       addNameSpaceas = true;
     }
     if (ct->getXsdtype() == n_sequence && getMinOccurs() == 1 && getMaxOccurs() == 1 && (parent->getXsdtype() == n_complexType || parent->getXsdtype() == n_sequence)) {
+      ComplexType* insertion_point = this;
       for (List<ComplexType*>::iterator c = ct->complexfields.begin(); c; c = c->Next) {
         ComplexType * newField = new ComplexType(*c->Data);
-        parent->complexfields.push_back(newField);
+        parent->complexfields.insert_after(newField, insertion_point);
+        insertion_point = newField;
         setParent(parent, newField);
-        parent->complexfields.back()->setModule(getModule());
+        newField->setModule(getModule());
         if (addNameSpaceas) {
-          parent->complexfields.back()->addVariant(V_namespaceAs, ct->getModule()->getTargetNamespace());
+          newField->addVariant(V_namespaceAs, ct->getModule()->getTargetNamespace());
         }
       }
     } else if (ct->getXsdtype() == n_all) {
       //If the parent optional, then every field is optional
+      ComplexType* insertion_point = this;
       for (List<ComplexType*>::iterator c = ct->complexfields.begin(); c; c = c->Next) {
         ComplexType* f = new ComplexType(*c->Data);
         if (getMinOccurs() == 0 && !f->enumerated) {
           f->isOptional = true;
         }
-        ((ComplexType*) parent)->complexfields.push_back(f);
+        ((ComplexType*) parent)->complexfields.insert_after(f, insertion_point);
+        insertion_point = f;
         setParent(parent, f);
         f->setModule(getModule());
         if (addNameSpaceas) {
