@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -265,7 +265,8 @@ void XSDName2TTCN3Name(const Mstring& in_str, const Mstring& in_namespace,
       }
 
       for (QualifiedNames::iterator used = used_names.begin(); used; used = used->Next) {
-        if (qual_name == used->Data) {
+        if ((!o_flag_used && qual_name == used->Data) ||
+            (o_flag_used && qual_name.name == used->Data.name)) {
           postfixing = true;
           break;
         }
@@ -280,7 +281,8 @@ void XSDName2TTCN3Name(const Mstring& in_str, const Mstring& in_namespace,
           Free(tmpname);
           tmpname = mprintf("%s_%d", qual_name.name.c_str(), counter);
           for (QualifiedNames::iterator used = used_names.begin(); used; used = used->Next) {
-            if (QualifiedName(/* empty_string ? */ ns_uri, Mstring(tmpname)) == used->Data) {
+            if ((!o_flag_used && QualifiedName(/* empty_string ? */ ns_uri, Mstring(tmpname)) == used->Data) ||
+                (o_flag_used && Mstring(tmpname) == used->Data.name)) {
               found = true;
               break;
             }
