@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -933,8 +933,9 @@ void SimpleType::printToFile(FILE * file) {
 
     int multiplicity = multi(module, outside_reference, this);
     const RootType *type_ref = outside_reference.get_ref();
-    if ((multiplicity > 1 && type_ref && type_ref->getModule() != module)
-       || name.convertedValue == type.convertedValue) {
+    if (!o_flag_used &&
+        ((multiplicity > 1 && type_ref && type_ref->getModule() != module)
+        || name.convertedValue == type.convertedValue)) {
       fprintf(file, "%s.", type_ref->getModule()->getModulename().c_str());
     }
 
