@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2018 Ericsson Telecom AB
+ * Copyright (c) 2000-2019 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -369,6 +369,11 @@ void TTCN3Module::generate_with_statement(FILE * file, List<NamespaceType> used_
 
 void TTCN3Module::TargetNamespace2ModuleName() {
   Mstring res(targetNamespace);
+  
+  if (N_flag_used && res == Mstring("NoTargetNamespace")) {
+    res += Mstring("_") + schemaname;
+    // TODO: delete '.xsd' or not? the standard CR is conflicted on this...
+  }
 
   if (z_flag_used) {
     char * found;
